# Contributing

* [Submit an issue](https://github.com/zseta/python-opensea/issues) to report a bug or suggest a new feature
* Submit a PR with a bugfix or a new feature.
* Write a blog post or a tutorial about how you are using the OpenSea API and this wrapper